@@ -17,4 +17,5 @@
 """
 Package "service.snmp"
 """
-from delphixpy.v1_9_3.web.service.snmp.snmp import *
+from delphixpy.v1_11_14.web.service.snmp import v3
+from delphixpy.v1_11_14.web.service.snmp import v2
