@@ -17,7 +17,9 @@
 """
 Package "storage"
 """
-from delphixpy.v1_10_3.web.storage import device
-from delphixpy.v1_10_3.web.storage import test
-from delphixpy.v1_10_3.web.storage import scrub
-from delphixpy.v1_10_3.web.storage import remove
+from delphixpy.v1_11_20.web.storage import objectStorage
+from delphixpy.v1_11_20.web.storage import remove
+from delphixpy.v1_11_20.web.storage import iscsi
+from delphixpy.v1_11_20.web.storage import test
+from delphixpy.v1_11_20.web.storage import device
+from delphixpy.v1_11_20.web.storage import scrub
