@@ -17,49 +17,40 @@
 """
 Package "web"
 """
-from . import transformation
-from . import action
-from . import passwordPolicy
-from . import notification
-from . import sourceconfig
 from . import authorization
-from . import about
-from . import source
-from . import registration
-from . import toolkit
-from . import fault
-from . import user
-from . import repository
-from . import namespace
-from . import role
-from . import host
-from . import storage
-from . import connectivity
-from . import maskingjob
-from . import session
-from . import selfservice
-from . import service
-from . import policy
-from . import job
-from . import timeflow
-from . import data
 from . import permission
-from . import snapshot
+from . import role
+from . import toolkit
+from . import environment
+from . import capacity
+from . import database
+from . import registration
+from . import host
+from . import data
+from . import repository
+from . import policy
+from . import user
 from . import alert
 from . import objects
-from . import replication
-from . import environment
-from . import repave
+from . import fault
+from . import group
+from . import connectivity
+from . import notification
 from . import delphix
-from . import usage
-from . import license
+from . import job
+from . import about
+from . import timeflow
+from . import action
+from . import jetstream
+from . import storage
+from . import domain
 from . import analytics
+from . import snapshot
+from . import sourceconfig
+from . import namespace
+from . import replication
+from . import source
+from . import service
 from . import system
 from . import network
-from . import database
-from . import timezone
-from . import domain
-from . import osadmin
-from . import theme
-from . import group
-from . import capacity
+from . import session
