@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +17,8 @@
 """
 Package "authorization"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy.web.authorization import configuration
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, authorization=None):
@@ -35,14 +29,13 @@ def create(engine, authorization=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param authorization: Payload object.
     :type authorization: :py:class:`delphixpy.web.vo.Authorization`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization"
     response = engine.post(url, authorization.to_dict(dirty=True) if authorization else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -55,7 +48,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.Authorization`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -69,14 +61,13 @@ def get_all(engine, user=None, target=None, effective=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param user: Lists permissions granted to the specified user.
-    :type user: ``TEXT_TYPE``
+    :type user: ``str``
     :param target: Lists the permissions granted on the specified object.
-    :type target: ``TEXT_TYPE``
+    :type target: ``str``
     :param effective: Also return inherited authorizations.
-    :type effective: ``TEXT_TYPE``
+    :type effective: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.Authorization`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization"
     query_params = {"user": user, "target": target, "effective": effective}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -98,7 +89,6 @@ def delete(engine, ref):
         :py:class:`delphixpy.web.objects.Authorization.Authorization` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -116,7 +106,6 @@ def filter_by_permission(engine, auth_filter_parameters):
         :py:class:`delphixpy.web.vo.AuthFilterParameters`
     :rtype: :py:class:`delphixpy.web.vo.AuthFilterResult`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization/filterByPermission"
     response = engine.post(url, auth_filter_parameters.to_dict(dirty=True) if auth_filter_parameters else None)
     result = response_validator.validate(response, engine)
@@ -134,7 +123,6 @@ def get_by_properties(engine, auth_get_by_properties_parameters):
         :py:class:`delphixpy.web.vo.AuthGetByPropertiesParameters`
     :rtype: :py:class:`delphixpy.web.vo.Authorization`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization/getByProperties"
     response = engine.post(url, auth_get_by_properties_parameters.to_dict(dirty=True) if auth_get_by_properties_parameters else None)
     result = response_validator.validate(response, engine)
