@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "capacity.snapshot"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get_all(engine, container=None, namespace=None, page_size=None, page_offset=None):
@@ -34,17 +28,16 @@ def get_all(engine, container=None, namespace=None, page_size=None, page_offset=
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param container: The container to list snapshot data for.
-    :type container: ``TEXT_TYPE``
+    :type container: ``str``
     :param namespace: The namespace to list snapshot data for. If null, will
         limit returned snapshots to the default namespace.
-    :type namespace: ``TEXT_TYPE`` *or* ``null``
+    :type namespace: ``str`` *or* ``null``
     :param page_size: Limit the number of entries returned.
     :type page_size: ``int``
     :param page_offset: Offset within list, in units of pageSize chunks.
     :type page_offset: ``int``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.SnapshotCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/capacity/snapshot"
     query_params = {"container": container, "namespace": namespace, "pageSize": page_size, "pageOffset": page_offset}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
