@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "capacity.system.historical"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get_all(engine, start_date=None, end_date=None, resolution=None):
@@ -33,16 +27,15 @@ def get_all(engine, start_date=None, end_date=None, resolution=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param start_date: Earliest date for which to list data.
-    :type start_date: ``TEXT_TYPE``
+    :type start_date: ``str``
     :param end_date: Latest date for which to list data.
-    :type end_date: ``TEXT_TYPE``
+    :type end_date: ``str``
     :param resolution: The time range each datapoint should represent, measured
         in seconds.
     :type resolution: ``int``
     :rtype: ``list`` of
         :py:class:`delphixpy.web.vo.HistoricalSystemCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/capacity/system/historical"
     query_params = {"startDate": start_date, "endDate": end_date, "resolution": resolution}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
