@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "environment.user"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, environment_user=None):
@@ -34,14 +28,13 @@ def create(engine, environment_user=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param environment_user: Payload object.
     :type environment_user: :py:class:`delphixpy.web.vo.EnvironmentUser`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/user"
     response = engine.post(url, environment_user.to_dict(dirty=True) if environment_user else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -55,7 +48,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.EnvironmentUser`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/user/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -69,10 +61,9 @@ def get_all(engine, environment=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param environment: Limit results to users within the given environment.
-    :type environment: ``TEXT_TYPE``
+    :type environment: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.EnvironmentUser`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/user"
     query_params = {"environment": environment}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -97,7 +88,6 @@ def update(engine, ref, environment_user=None):
     :param environment_user: Payload object.
     :type environment_user: :py:class:`delphixpy.web.vo.EnvironmentUser`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/user/%s" % ref
     response = engine.post(url, environment_user.to_dict(dirty=True) if environment_user else None)
     result = response_validator.validate(response, engine)
@@ -117,7 +107,6 @@ def delete(engine, ref, delete_parameters=None):
     :param delete_parameters: Payload object.
     :type delete_parameters: :py:class:`delphixpy.web.vo.DeleteParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/user/%s/delete" % ref
     response = engine.post(url, delete_parameters.to_dict(dirty=True) if delete_parameters else None)
     result = response_validator.validate(response, engine)
