@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "environment.windows.clusterinstance"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get_all(engine, availabilitygroup=None):
@@ -34,10 +28,9 @@ def get_all(engine, availabilitygroup=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param availabilitygroup: A reference to the SQL Server Availability Group
         this instance belongs to.
-    :type availabilitygroup: ``TEXT_TYPE``
+    :type availabilitygroup: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.MSSqlClusterInstance`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/windows/clusterinstance"
     query_params = {"availabilitygroup": availabilitygroup}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
