@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +17,8 @@
 """
 Package "fault"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy.web.fault import effect
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get(engine, ref):
@@ -38,7 +32,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.Fault`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/fault/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -53,20 +46,20 @@ def get_all(engine, target=None, targets=None, severity=None, status=None, from_
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param target: The reference to the Delphix user-visible object associated
         with the fault.
-    :type target: ``TEXT_TYPE``
+    :type target: ``str``
     :param targets: The list of references to Delphix user-visible objects
         associated with the faults.
-    :type targets: ``list`` of ``TEXT_TYPE``
+    :type targets: ``list`` of ``str``
     :param severity: The impact of the fault on the system: CRITICAL or
         WARNING. *(permitted values: CRITICAL, WARNING)*
-    :type severity: ``TEXT_TYPE``
+    :type severity: ``str``
     :param status: The status of the fault: ACTIVE, RESOLVED or IGNORED.
         *(permitted values: ACTIVE, RESOLVED, IGNORED)*
-    :type status: ``TEXT_TYPE``
+    :type status: ``str``
     :param from_date: Start date to use for the search.
-    :type from_date: ``TEXT_TYPE``
+    :type from_date: ``str``
     :param to_date: End date to use for the search.
-    :type to_date: ``TEXT_TYPE``
+    :type to_date: ``str``
     :param page_size: Limit the number of faults returned.
     :type page_size: ``int``
     :param page_offset: Offset within fault list, in units of pageSize chunks.
@@ -75,15 +68,14 @@ def get_all(engine, target=None, targets=None, severity=None, status=None, from_
     :type max_total: ``int``
     :param sort_by: Search results are sorted by the field provided.
         *(permitted values: severity, dateDiagnosed, title, targetName)*
-    :type sort_by: ``TEXT_TYPE``
+    :type sort_by: ``str``
     :param ascending: True if results are to be returned in ascending order.
     :type ascending: ``bool``
     :param search_text: Limit search results to only include faults that have
         searchText string in severity, title, targetName.
-    :type search_text: ``TEXT_TYPE``
+    :type search_text: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.Fault`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/fault"
     query_params = {"target": target, "targets": targets, "severity": severity, "status": status, "fromDate": from_date, "toDate": to_date, "pageSize": page_size, "pageOffset": page_offset, "maxTotal": max_total, "sortBy": sort_by, "ascending": ascending, "searchText": search_text}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -108,7 +100,6 @@ def resolve(engine, ref, fault_resolve_parameters):
     :type fault_resolve_parameters:
         :py:class:`delphixpy.web.vo.FaultResolveParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/fault/%s/resolve" % ref
     response = engine.post(url, fault_resolve_parameters.to_dict(dirty=True) if fault_resolve_parameters else None)
     result = response_validator.validate(response, engine)
@@ -122,7 +113,6 @@ def resolve_all(engine):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/fault/resolveAll"
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -139,7 +129,6 @@ def resolve_or_ignore_selected(engine, resolve_or_ignore_selected_faults_paramet
     :type resolve_or_ignore_selected_faults_parameters:
         :py:class:`delphixpy.web.vo.ResolveOrIgnoreSelectedFaultsParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/fault/resolveOrIgnoreSelected"
     response = engine.post(url, resolve_or_ignore_selected_faults_parameters.to_dict(dirty=True) if resolve_or_ignore_selected_faults_parameters else None)
     result = response_validator.validate(response, engine)
@@ -153,7 +142,6 @@ def unignore_all(engine):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/fault/unignoreAll"
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -170,7 +158,6 @@ def reset_ignored(engine, reset_ignored_faults_parameters):
     :type reset_ignored_faults_parameters:
         :py:class:`delphixpy.web.vo.ResetIgnoredFaultsParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/fault/resetIgnored"
     response = engine.post(url, reset_ignored_faults_parameters.to_dict(dirty=True) if reset_ignored_faults_parameters else None)
     result = response_validator.validate(response, engine)
