@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,8 +17,6 @@
 """
 Package "host.privilegeElevation.profileScript"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy import response_validator
 
 def create(engine, host_privilege_elevation_profile_script=None):
@@ -31,14 +28,13 @@ def create(engine, host_privilege_elevation_profile_script=None):
     :param host_privilege_elevation_profile_script: Payload object.
     :type host_privilege_elevation_profile_script:
         :py:class:`delphixpy.web.vo.HostPrivilegeElevationProfileScript`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profileScript"
     response = engine.post(url, host_privilege_elevation_profile_script.to_dict(dirty=True) if host_privilege_elevation_profile_script else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -51,7 +47,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.HostPrivilegeElevationProfileScript`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profileScript/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -67,7 +62,6 @@ def get_all(engine):
     :rtype: ``list`` of
         :py:class:`delphixpy.web.vo.HostPrivilegeElevationProfileScript`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profileScript"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -87,7 +81,6 @@ def update(engine, ref, host_privilege_elevation_profile_script=None):
     :type host_privilege_elevation_profile_script:
         :py:class:`delphixpy.web.vo.HostPrivilegeElevationProfileScript`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profileScript/%s" % ref
     response = engine.post(url, host_privilege_elevation_profile_script.to_dict(dirty=True) if host_privilege_elevation_profile_script else None)
     result = response_validator.validate(response, engine)
@@ -104,7 +97,6 @@ def delete(engine, ref):
         evationProfileScript.HostPrivilegeElevationProfileScript` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profileScript/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
