@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "maskingjob"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get(engine, ref):
@@ -37,7 +31,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.MaskingJob`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/maskingjob/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -52,10 +45,9 @@ def get_all(engine, container=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param container: List only the Masking Jobs that are associated with the
         provided container.
-    :type container: ``TEXT_TYPE``
+    :type container: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.MaskingJob`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/maskingjob"
     query_params = {"container": container}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -79,7 +71,6 @@ def update(engine, ref, masking_job=None):
     :param masking_job: Payload object.
     :type masking_job: :py:class:`delphixpy.web.vo.MaskingJob`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/maskingjob/%s" % ref
     response = engine.post(url, masking_job.to_dict(dirty=True) if masking_job else None)
     result = response_validator.validate(response, engine)
@@ -96,7 +87,6 @@ def delete(engine, ref):
         :py:class:`delphixpy.web.objects.MaskingJob.MaskingJob` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/maskingjob/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -113,7 +103,6 @@ def create(engine, masking_job):
     :param masking_job: Payload object.
     :type masking_job: :py:class:`delphixpy.web.vo.MaskingJob`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/maskingjob/create"
     response = engine.post(url, masking_job.to_dict(dirty=True) if masking_job else None)
     result = response_validator.validate(response, engine)
@@ -128,7 +117,6 @@ def fetch(engine):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/maskingjob/fetch"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -141,12 +129,11 @@ def get_local_service_status(engine):
 
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/maskingjob/getLocalServiceStatus"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
