@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "namespace"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get(engine, ref):
@@ -37,7 +31,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.Namespace`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/namespace/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -52,7 +45,6 @@ def get_all(engine):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.Namespace`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/namespace"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -71,7 +63,6 @@ def update(engine, ref, namespace=None):
     :param namespace: Payload object.
     :type namespace: :py:class:`delphixpy.web.vo.Namespace`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/namespace/%s" % ref
     response = engine.post(url, namespace.to_dict(dirty=True) if namespace else None)
     result = response_validator.validate(response, engine)
@@ -88,7 +79,6 @@ def delete(engine, ref):
         :py:class:`delphixpy.web.objects.Namespace.Namespace` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/namespace/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -108,7 +98,6 @@ def failover(engine, ref, namespace_failover_parameters=None):
     :type namespace_failover_parameters:
         :py:class:`delphixpy.web.vo.NamespaceFailoverParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/namespace/%s/failover" % ref
     response = engine.post(url, namespace_failover_parameters.to_dict(dirty=True) if namespace_failover_parameters else None)
     result = response_validator.validate(response, engine)
@@ -125,13 +114,61 @@ def discard(engine, ref):
         :py:class:`delphixpy.web.objects.Namespace.Namespace` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/namespace/%s/discard" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
+def failback(engine, ref):
+    """
+    Failback a previously failedover namespace.
+
+    :param engine: The Delphix Engine
+    :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
+    :param ref: Reference to a
+        :py:class:`delphixpy.web.objects.Namespace.Namespace` object
+    :type ref: ``str``
+    """
+    url = "/resources/json/delphix/namespace/%s/failback" % ref
+    response = engine.post(url, None)
+    result = response_validator.validate(response, engine)
+    raw_result = getattr(engine, 'raw_result', False)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
+
+def commit_failover(engine, ref):
+    """
+    Commits the failover of a given namespace and discards the failback state.
+
+    :param engine: The Delphix Engine
+    :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
+    :param ref: Reference to a
+        :py:class:`delphixpy.web.objects.Namespace.Namespace` object
+    :type ref: ``str``
+    """
+    url = "/resources/json/delphix/namespace/%s/commitFailover" % ref
+    response = engine.post(url, None)
+    result = response_validator.validate(response, engine)
+    raw_result = getattr(engine, 'raw_result', False)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
+
+def get_failback_capability(engine, ref):
+    """
+    Get failback capability of a namespace.
+
+    :param engine: The Delphix Engine
+    :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
+    :param ref: Reference to a
+        :py:class:`delphixpy.web.objects.Namespace.Namespace` object
+    :type ref: ``str``
+    :rtype: :py:class:`delphixpy.web.vo.FailbackCapability`
+    """
+    url = "/resources/json/delphix/namespace/%s/getFailbackCapability" % ref
+    response = engine.get(url)
+    result = response_validator.validate(response, engine)
+    raw_result = getattr(engine, 'raw_result', False)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['FailbackCapability'], returns_list=False, raw_result=raw_result)
+
 def translate(engine, ref, object=None):
     """
     Returns the local object corresponding to the remote reference.
@@ -142,10 +179,9 @@ def translate(engine, ref, object=None):
         :py:class:`delphixpy.web.objects.Namespace.Namespace` object
     :type ref: ``str``
     :param object: None
-    :type object: ``TEXT_TYPE``
-    :rtype: ``TEXT_TYPE``
+    :type object: ``str``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/namespace/%s/translate" % ref
     query_params = {"object": object}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -155,7 +191,7 @@ def translate(engine, ref, object=None):
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def lookup(engine, tag=None):
     """
@@ -164,10 +200,9 @@ def lookup(engine, tag=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param tag: The value of the namespace tag to search for.
-    :type tag: ``TEXT_TYPE``
+    :type tag: ``str``
     :rtype: :py:class:`delphixpy.web.vo.Namespace`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/namespace/lookup"
     query_params = {"tag": tag}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
