@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,8 +17,6 @@
 """
 Package "network.route"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy import response_validator
 
 def create(engine, network_route=None):
@@ -30,14 +27,13 @@ def create(engine, network_route=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param network_route: Payload object.
     :type network_route: :py:class:`delphixpy.web.vo.NetworkRoute`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/route"
     response = engine.post(url, network_route.to_dict(dirty=True) if network_route else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get_all(engine):
     """
@@ -47,7 +43,6 @@ def get_all(engine):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.NetworkRoute`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/route"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,7 +58,6 @@ def add(engine, network_route=None):
     :param network_route: Payload object.
     :type network_route: :py:class:`delphixpy.web.vo.NetworkRoute`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/route/add"
     response = engine.post(url, network_route.to_dict(dirty=True) if network_route else None)
     result = response_validator.validate(response, engine)
@@ -79,7 +73,6 @@ def delete(engine, network_route=None):
     :param network_route: Payload object.
     :type network_route: :py:class:`delphixpy.web.vo.NetworkRoute`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/route/delete"
     response = engine.post(url, network_route.to_dict(dirty=True) if network_route else None)
     result = response_validator.validate(response, engine)
@@ -97,7 +90,6 @@ def lookup(engine, network_route_lookup_parameters):
         :py:class:`delphixpy.web.vo.NetworkRouteLookupParameters`
     :rtype: :py:class:`delphixpy.web.vo.NetworkRoute`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/route/lookup"
     response = engine.post(url, network_route_lookup_parameters.to_dict(dirty=True) if network_route_lookup_parameters else None)
     result = response_validator.validate(response, engine)
