@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "notification"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get_all(engine, channel=None, timeout=None, max=None):
@@ -33,15 +27,14 @@ def get_all(engine, channel=None, timeout=None, max=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param channel: Client-specific ID to specify an independent channel.
-    :type channel: ``TEXT_TYPE``
+    :type channel: ``str``
     :param timeout: Timeout, in milliseconds, to wait for one or more
         responses.
-    :type timeout: ``TEXT_TYPE``
+    :type timeout: ``str``
     :param max: Maximum number of entries to return at once.
-    :type max: ``TEXT_TYPE``
+    :type max: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.Notification`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/notification"
     query_params = {"channel": channel, "timeout": timeout, "max": max}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
