@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "policy"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, policy=None):
@@ -34,14 +28,13 @@ def create(engine, policy=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param policy: Payload object.
     :type policy: :py:class:`delphixpy.web.vo.Policy`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy"
     response = engine.post(url, policy.to_dict(dirty=True) if policy else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -54,7 +47,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.Policy`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -68,15 +60,14 @@ def get_all(engine, type=None, target=None, effective=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param type: Limit policies to those of the given type.
-    :type type: ``TEXT_TYPE``
+    :type type: ``str``
     :param target: Limit policies to those affecting a particular object on the
         system.
-    :type target: ``TEXT_TYPE``
+    :type target: ``str``
     :param effective: Whether to include effective policies for the target.
-    :type effective: ``TEXT_TYPE``
+    :type effective: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.Policy`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy"
     query_params = {"type": type, "target": target, "effective": effective}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -100,7 +91,6 @@ def update(engine, ref, policy=None):
     :param policy: Payload object.
     :type policy: :py:class:`delphixpy.web.vo.Policy`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/%s" % ref
     response = engine.post(url, policy.to_dict(dirty=True) if policy else None)
     result = response_validator.validate(response, engine)
@@ -117,7 +107,6 @@ def delete(engine, ref):
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -137,7 +126,6 @@ def apply(engine, ref, policy_apply_target_parameters):
     :type policy_apply_target_parameters:
         :py:class:`delphixpy.web.vo.PolicyApplyTargetParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/%s/apply" % ref
     response = engine.post(url, policy_apply_target_parameters.to_dict(dirty=True) if policy_apply_target_parameters else None)
     result = response_validator.validate(response, engine)
@@ -157,7 +145,6 @@ def unapply(engine, ref, policy_apply_target_parameters):
     :type policy_apply_target_parameters:
         :py:class:`delphixpy.web.vo.PolicyApplyTargetParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/%s/unapply" % ref
     response = engine.post(url, policy_apply_target_parameters.to_dict(dirty=True) if policy_apply_target_parameters else None)
     result = response_validator.validate(response, engine)
@@ -173,12 +160,11 @@ def create_and_apply(engine, policy_create_and_apply_parameters):
     :param policy_create_and_apply_parameters: Payload object.
     :type policy_create_and_apply_parameters:
         :py:class:`delphixpy.web.vo.PolicyCreateAndApplyParameters`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/createAndApply"
     response = engine.post(url, policy_create_and_apply_parameters.to_dict(dirty=True) if policy_create_and_apply_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
