@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "replication.targetstate"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get(engine, ref):
@@ -37,7 +31,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.ReplicationTargetState`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/targetstate/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -52,7 +45,6 @@ def get_all(engine):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.ReplicationTargetState`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/targetstate"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -66,10 +58,9 @@ def get_by_namespace(engine, namespace=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param namespace: Namespace object reference.
-    :type namespace: ``TEXT_TYPE``
+    :type namespace: ``str``
     :rtype: :py:class:`delphixpy.web.vo.ReplicationTargetState`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/targetstate/getByNamespace"
     query_params = {"namespace": namespace}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
