@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +17,8 @@
 """
 Package "repository"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy.web.repository import template
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, source_repository=None):
@@ -35,14 +29,13 @@ def create(engine, source_repository=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param source_repository: Payload object.
     :type source_repository: :py:class:`delphixpy.web.vo.SourceRepository`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository"
     response = engine.post(url, source_repository.to_dict(dirty=True) if source_repository else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -56,7 +49,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.SourceRepository`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -71,10 +63,9 @@ def get_all(engine, environment=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param environment: Restrict source repositories belong to the specified
         environment.
-    :type environment: ``TEXT_TYPE``
+    :type environment: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.SourceRepository`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository"
     query_params = {"environment": environment}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -99,7 +90,6 @@ def update(engine, ref, source_repository=None):
     :param source_repository: Payload object.
     :type source_repository: :py:class:`delphixpy.web.vo.SourceRepository`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/%s" % ref
     response = engine.post(url, source_repository.to_dict(dirty=True) if source_repository else None)
     result = response_validator.validate(response, engine)
@@ -117,7 +107,6 @@ def delete(engine, ref):
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -135,7 +124,6 @@ def compatible_repositories(engine, compatible_repositories_parameters):
         :py:class:`delphixpy.web.vo.CompatibleRepositoriesParameters`
     :rtype: :py:class:`delphixpy.web.vo.CompatibleRepositoriesResult`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/compatibleRepositories"
     response = engine.post(url, compatible_repositories_parameters.to_dict(dirty=True) if compatible_repositories_parameters else None)
     result = response_validator.validate(response, engine)
