@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,8 +17,6 @@
 """
 Package "repository.template"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy import response_validator
 
 def create(engine, source_repository_template=None):
@@ -31,14 +28,13 @@ def create(engine, source_repository_template=None):
     :param source_repository_template: Payload object.
     :type source_repository_template:
         :py:class:`delphixpy.web.vo.SourceRepositoryTemplate`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/template"
     response = engine.post(url, source_repository_template.to_dict(dirty=True) if source_repository_template else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -51,7 +47,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.SourceRepositoryTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/template/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -66,7 +61,6 @@ def get_all(engine):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.SourceRepositoryTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/template"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -86,7 +80,6 @@ def update(engine, ref, source_repository_template=None):
     :type source_repository_template:
         :py:class:`delphixpy.web.vo.SourceRepositoryTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/template/%s" % ref
     response = engine.post(url, source_repository_template.to_dict(dirty=True) if source_repository_template else None)
     result = response_validator.validate(response, engine)
@@ -103,7 +96,6 @@ def delete(engine, ref):
         yTemplate.SourceRepositoryTemplate` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/template/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
