@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "selfservice.bookmark"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, js_bookmark_create_parameters):
@@ -35,14 +29,13 @@ def create(engine, js_bookmark_create_parameters):
     :param js_bookmark_create_parameters: Payload object.
     :type js_bookmark_create_parameters:
         :py:class:`delphixpy.web.vo.JSBookmarkCreateParameters`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark"
     response = engine.post(url, js_bookmark_create_parameters.to_dict(dirty=True) if js_bookmark_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -55,7 +48,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.JSBookmark`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -71,13 +63,12 @@ def get_all(engine, container=None, template=None):
     :param container: List all usable bookmarks accessible to the specified
         data container. This option is mutually exclusive with all other
         options.
-    :type container: ``TEXT_TYPE``
+    :type container: ``str``
     :param template: List all usable bookmarks created in the specified data
         template. This option is mutually exclusive with all other options.
-    :type template: ``TEXT_TYPE``
+    :type template: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSBookmark`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark"
     query_params = {"container": container, "template": template}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -101,7 +92,6 @@ def update(engine, ref, js_bookmark=None):
     :param js_bookmark: Payload object.
     :type js_bookmark: :py:class:`delphixpy.web.vo.JSBookmark`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s" % ref
     response = engine.post(url, js_bookmark.to_dict(dirty=True) if js_bookmark else None)
     result = response_validator.validate(response, engine)
@@ -118,7 +108,6 @@ def delete(engine, ref):
         :py:class:`delphixpy.web.objects.JSBookmark.JSBookmark` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -135,7 +124,6 @@ def share(engine, ref):
         :py:class:`delphixpy.web.objects.JSBookmark.JSBookmark` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s/share" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -152,7 +140,6 @@ def unshare(engine, ref):
         :py:class:`delphixpy.web.objects.JSBookmark.JSBookmark` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s/unshare" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -170,7 +157,6 @@ def get_create_bookmark_operation(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s/getCreateBookmarkOperation" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -188,7 +174,6 @@ def list_data_children(engine, ref):
     :type ref: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSDataChild`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s/listDataChildren" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -204,13 +189,12 @@ def list_by_top_checkouts(engine, template=None, max_result_size=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param template: The given data template.
-    :type template: ``TEXT_TYPE``
+    :type template: ``str``
     :param max_result_size: The maximum number of results to return. A value of
         0 means all are returned.
     :type max_result_size: ``int``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSBookmark`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/listByTopCheckouts"
     query_params = {"template": template, "maxResultSize": max_result_size}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
