@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "selfservice.branch"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, js_branch_create_parameters):
@@ -35,14 +29,13 @@ def create(engine, js_branch_create_parameters):
     :param js_branch_create_parameters: Payload object.
     :type js_branch_create_parameters:
         :py:class:`delphixpy.web.vo.JSBranchCreateParameters`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/branch"
     response = engine.post(url, js_branch_create_parameters.to_dict(dirty=True) if js_branch_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -55,7 +48,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.JSBranch`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/branch/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -69,10 +61,9 @@ def get_all(engine, data_layout=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param data_layout: List branches belonging to the given data layout.
-    :type data_layout: ``TEXT_TYPE``
+    :type data_layout: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSBranch`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/branch"
     query_params = {"dataLayout": data_layout}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -96,7 +87,6 @@ def update(engine, ref, js_branch=None):
     :param js_branch: Payload object.
     :type js_branch: :py:class:`delphixpy.web.vo.JSBranch`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/branch/%s" % ref
     response = engine.post(url, js_branch.to_dict(dirty=True) if js_branch else None)
     result = response_validator.validate(response, engine)
@@ -113,7 +103,6 @@ def delete(engine, ref):
         :py:class:`delphixpy.web.objects.JSBranch.JSBranch` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/branch/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -130,7 +119,6 @@ def activate(engine, ref):
         :py:class:`delphixpy.web.objects.JSBranch.JSBranch` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/branch/%s/activate" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
