@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "selfservice.container"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, js_data_container_create_parameters):
@@ -35,14 +29,13 @@ def create(engine, js_data_container_create_parameters):
     :param js_data_container_create_parameters: Payload object.
     :type js_data_container_create_parameters:
         :py:class:`delphixpy.web.vo.JSDataContainerCreateParameters`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container"
     response = engine.post(url, js_data_container_create_parameters.to_dict(dirty=True) if js_data_container_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -56,7 +49,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.JSDataContainer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -72,18 +64,17 @@ def get_all(engine, owner=None, template=None, independent_only=None):
     :param owner: Restrict data containers to those belonging to the specified
         user.This option is mutually exclusive with the "template" and
         "independentOnly" options.
-    :type owner: ``TEXT_TYPE``
+    :type owner: ``str``
     :param template: Restrict data containers to those provisioned from the
         specified template. This option is mutually exclusive with the "owner"
         and "independentOnly" options.
-    :type template: ``TEXT_TYPE``
+    :type template: ``str``
     :param independent_only: Restrict data containers to independent data
         containers that do not have templates. This option is mutually
         exclusive with the "template" and "owner" options.
     :type independent_only: ``bool``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSDataContainer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container"
     query_params = {"owner": owner, "template": template, "independentOnly": independent_only}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -108,7 +99,6 @@ def update(engine, ref, js_data_container=None):
     :param js_data_container: Payload object.
     :type js_data_container: :py:class:`delphixpy.web.vo.JSDataContainer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s" % ref
     response = engine.post(url, js_data_container.to_dict(dirty=True) if js_data_container else None)
     result = response_validator.validate(response, engine)
@@ -129,7 +119,6 @@ def delete(engine, ref, js_data_container_delete_parameters=None):
     :type js_data_container_delete_parameters:
         :py:class:`delphixpy.web.vo.JSDataContainerDeleteParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/delete" % ref
     response = engine.post(url, js_data_container_delete_parameters.to_dict(dirty=True) if js_data_container_delete_parameters else None)
     result = response_validator.validate(response, engine)
@@ -150,7 +139,6 @@ def refresh(engine, ref, js_data_container_refresh_parameters=None):
     :type js_data_container_refresh_parameters:
         :py:class:`delphixpy.web.vo.JSDataContainerRefreshParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/refresh" % ref
     response = engine.post(url, js_data_container_refresh_parameters.to_dict(dirty=True) if js_data_container_refresh_parameters else None)
     result = response_validator.validate(response, engine)
@@ -172,7 +160,6 @@ def restore(engine, ref, js_data_container_restore_parameters):
     :type js_data_container_restore_parameters:
         :py:class:`delphixpy.web.vo.JSDataContainerRestoreParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/restore" % ref
     response = engine.post(url, js_data_container_restore_parameters.to_dict(dirty=True) if js_data_container_restore_parameters else None)
     result = response_validator.validate(response, engine)
@@ -190,7 +177,6 @@ def enable(engine, ref):
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/enable" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -208,7 +194,6 @@ def disable(engine, ref):
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/disable" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -226,7 +211,6 @@ def recover(engine, ref):
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/recover" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -247,7 +231,6 @@ def reset(engine, ref, js_data_container_reset_parameters=None):
     :type js_data_container_reset_parameters:
         :py:class:`delphixpy.web.vo.JSDataContainerResetParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/reset" % ref
     response = engine.post(url, js_data_container_reset_parameters.to_dict(dirty=True) if js_data_container_reset_parameters else None)
     result = response_validator.validate(response, engine)
@@ -269,7 +252,6 @@ def undo(engine, ref, js_data_container_undo_parameters):
     :type js_data_container_undo_parameters:
         :py:class:`delphixpy.web.vo.JSDataContainerUndoParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/undo" % ref
     response = engine.post(url, js_data_container_undo_parameters.to_dict(dirty=True) if js_data_container_undo_parameters else None)
     result = response_validator.validate(response, engine)
@@ -289,14 +271,13 @@ def get_active_branch_at_time(engine, ref, js_data_container_active_branch_param
     :param js_data_container_active_branch_parameters: Payload object.
     :type js_data_container_active_branch_parameters:
         :py:class:`delphixpy.web.vo.JSDataContainerActiveBranchParameters`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/getActiveBranchAtTime" % ref
     response = engine.post(url, js_data_container_active_branch_parameters.to_dict(dirty=True) if js_data_container_active_branch_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def add_owner(engine, ref, js_data_container_modify_owner_parameters):
     """
@@ -313,7 +294,6 @@ def add_owner(engine, ref, js_data_container_modify_owner_parameters):
     :type js_data_container_modify_owner_parameters:
         :py:class:`delphixpy.web.vo.JSDataContainerModifyOwnerParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/addOwner" % ref
     response = engine.post(url, js_data_container_modify_owner_parameters.to_dict(dirty=True) if js_data_container_modify_owner_parameters else None)
     result = response_validator.validate(response, engine)
@@ -335,7 +315,6 @@ def remove_owner(engine, ref, js_data_container_modify_owner_parameters):
     :type js_data_container_modify_owner_parameters:
         :py:class:`delphixpy.web.vo.JSDataContainerModifyOwnerParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/removeOwner" % ref
     response = engine.post(url, js_data_container_modify_owner_parameters.to_dict(dirty=True) if js_data_container_modify_owner_parameters else None)
     result = response_validator.validate(response, engine)
@@ -357,7 +336,6 @@ def lock(engine, ref, js_data_container_lock_parameters):
     :type js_data_container_lock_parameters:
         :py:class:`delphixpy.web.vo.JSDataContainerLockParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/lock" % ref
     response = engine.post(url, js_data_container_lock_parameters.to_dict(dirty=True) if js_data_container_lock_parameters else None)
     result = response_validator.validate(response, engine)
@@ -375,7 +353,6 @@ def unlock(engine, ref):
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/%s/unlock" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -390,13 +367,12 @@ def list_by_top_operation_count(engine, template=None, max_result_size=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param template: The given data template.
-    :type template: ``TEXT_TYPE``
+    :type template: ``str``
     :param max_result_size: The maximum number of results to return. A value of
         0 means all are returned.
     :type max_result_size: ``int``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSDataContainer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/listByTopOperationCount"
     query_params = {"template": template, "maxResultSize": max_result_size}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -415,10 +391,9 @@ def count_by_owner(engine, owner=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param owner: None
-    :type owner: ``TEXT_TYPE``
+    :type owner: ``str``
     :rtype: ``int``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/container/countByOwner"
     query_params = {"owner": owner}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
