@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "selfservice.datasource"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get(engine, ref):
@@ -37,7 +31,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.JSDataSource`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/datasource/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -52,13 +45,12 @@ def get_all(engine, data_layout=None, container=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param data_layout: List the sources associated with the given data layout
         reference.
-    :type data_layout: ``TEXT_TYPE``
+    :type data_layout: ``str``
     :param container: List the source associated with the given container
         reference.
-    :type container: ``TEXT_TYPE``
+    :type container: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSDataSource`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/datasource"
     query_params = {"dataLayout": data_layout, "container": container}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -82,7 +74,6 @@ def update(engine, ref, js_data_source=None):
     :param js_data_source: Payload object.
     :type js_data_source: :py:class:`delphixpy.web.vo.JSDataSource`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/datasource/%s" % ref
     response = engine.post(url, js_data_source.to_dict(dirty=True) if js_data_source else None)
     result = response_validator.validate(response, engine)
@@ -102,7 +93,6 @@ def data_timestamps(engine, js_source_data_timestamp_parameters):
         :py:class:`delphixpy.web.vo.JSSourceDataTimestampParameters`
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSSourceDataTimestamp`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/datasource/dataTimestamps"
     response = engine.post(url, js_source_data_timestamp_parameters.to_dict(dirty=True) if js_source_data_timestamp_parameters else None)
     result = response_validator.validate(response, engine)
