@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +17,8 @@
 """
 Package "selfservice.usage.bookmark"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy.web.selfservice.usage.bookmark import tag
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def list_bookmark_usage_data(engine, data_layout=None):
@@ -36,10 +30,9 @@ def list_bookmark_usage_data(engine, data_layout=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param data_layout: The usage information for the bookmarks on this data
         container will be returned.
-    :type data_layout: ``TEXT_TYPE``
+    :type data_layout: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSBookmarkUsageData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/usage/bookmark/listBookmarkUsageData"
     query_params = {"dataLayout": data_layout}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
