@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "selfservice.usage.template"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def list_template_usage_data(engine, template=None):
@@ -35,10 +29,9 @@ def list_template_usage_data(engine, template=None):
     :param template: If passed in, this query parameter restricts the API to
         only return the usage information for the given data template. By
         default, the usage information for all data templates is returned.
-    :type template: ``TEXT_TYPE``
+    :type template: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSTemplateUsageData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/usage/template/listTemplateUsageData"
     query_params = {"template": template}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
