@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "selfservice.usagedata.operationcount"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get(engine, ref):
@@ -37,7 +31,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.JSWeeklyOperationCount`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/usagedata/operationcount/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -53,10 +46,9 @@ def get_all(engine, usage_object=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param usage_object: Restrict usage data to that related to a specific
         object.
-    :type usage_object: ``TEXT_TYPE``
+    :type usage_object: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.JSWeeklyOperationCount`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/usagedata/operationcount"
     query_params = {"usageObject": usage_object}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
