@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,8 +17,6 @@
 """
 Package "service.fluentd.configuration"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy import response_validator
 
 def create(engine, fluentd_config=None):
@@ -30,14 +27,13 @@ def create(engine, fluentd_config=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param fluentd_config: Payload object.
     :type fluentd_config: :py:class:`delphixpy.web.vo.FluentdConfig`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/fluentd/configuration"
     response = engine.post(url, fluentd_config.to_dict(dirty=True) if fluentd_config else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -50,7 +46,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.FluentdConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/fluentd/configuration/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -65,7 +60,6 @@ def get_all(engine):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.FluentdConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/fluentd/configuration"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -84,7 +78,6 @@ def update(engine, ref, fluentd_config=None):
     :param fluentd_config: Payload object.
     :type fluentd_config: :py:class:`delphixpy.web.vo.FluentdConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/fluentd/configuration/%s" % ref
     response = engine.post(url, fluentd_config.to_dict(dirty=True) if fluentd_config else None)
     result = response_validator.validate(response, engine)
@@ -101,7 +94,6 @@ def delete(engine, ref):
         :py:class:`delphixpy.web.objects.FluentdConfig.FluentdConfig` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/fluentd/configuration/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
