@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,8 +17,6 @@
 """
 Package "service.insight.splunkHec"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy import response_validator
 
 def create(engine, splunk_hec_config=None):
@@ -30,14 +27,13 @@ def create(engine, splunk_hec_config=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param splunk_hec_config: Payload object.
     :type splunk_hec_config: :py:class:`delphixpy.web.vo.SplunkHecConfig`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec"
     response = engine.post(url, splunk_hec_config.to_dict(dirty=True) if splunk_hec_config else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -51,7 +47,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.SplunkHecConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -66,7 +61,6 @@ def get_all(engine):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.SplunkHecConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -86,7 +80,6 @@ def update(engine, ref, splunk_hec_config=None):
     :param splunk_hec_config: Payload object.
     :type splunk_hec_config: :py:class:`delphixpy.web.vo.SplunkHecConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec/%s" % ref
     response = engine.post(url, splunk_hec_config.to_dict(dirty=True) if splunk_hec_config else None)
     result = response_validator.validate(response, engine)
@@ -104,7 +97,6 @@ def delete(engine, ref):
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -120,12 +112,11 @@ def test(engine, splunk_hec_config=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param splunk_hec_config: Payload object.
     :type splunk_hec_config: :py:class:`delphixpy.web.vo.SplunkHecConfig`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec/test"
     response = engine.post(url, splunk_hec_config.to_dict(dirty=True) if splunk_hec_config else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
