@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "service.tls.caCertificate"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, pem_certificate):
@@ -34,14 +28,13 @@ def create(engine, pem_certificate):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param pem_certificate: Payload object.
     :type pem_certificate: :py:class:`delphixpy.web.vo.PemCertificate`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/caCertificate"
     response = engine.post(url, pem_certificate.to_dict(dirty=True) if pem_certificate else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -54,7 +47,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.CaCertificate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/caCertificate/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -72,7 +64,6 @@ def get_all(engine, delphix_ca=None):
     :type delphix_ca: ``bool``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.CaCertificate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/caCertificate"
     query_params = {"delphixCa": delphix_ca}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -94,7 +85,6 @@ def delete(engine, ref):
         :py:class:`delphixpy.web.objects.CaCertificate.CaCertificate` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/caCertificate/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -112,7 +102,6 @@ def to_pem(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.PemCertificate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/caCertificate/%s/toPEM" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -130,7 +119,6 @@ def accept(engine, ref):
         :py:class:`delphixpy.web.objects.CaCertificate.CaCertificate` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/caCertificate/%s/accept" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -148,7 +136,6 @@ def fetch(engine, certificate_fetch_parameters=None):
         :py:class:`delphixpy.web.vo.CertificateFetchParameters`
     :rtype: :py:class:`delphixpy.web.vo.CaCertificate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/caCertificate/fetch"
     response = engine.post(url, certificate_fetch_parameters.to_dict(dirty=True) if certificate_fetch_parameters else None)
     result = response_validator.validate(response, engine)
@@ -165,7 +152,6 @@ def show_provided_certificate(engine, pem_certificate):
     :type pem_certificate: :py:class:`delphixpy.web.vo.PemCertificate`
     :rtype: :py:class:`delphixpy.web.vo.CaCertificate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/caCertificate/showProvidedCertificate"
     response = engine.post(url, pem_certificate.to_dict(dirty=True) if pem_certificate else None)
     result = response_validator.validate(response, engine)
