@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,8 +17,6 @@
 """
 Package "service.tls.csr"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy import response_validator
 
 def create(engine, certificate_signing_request_create_parameters):
@@ -31,14 +28,13 @@ def create(engine, certificate_signing_request_create_parameters):
     :param certificate_signing_request_create_parameters: Payload object.
     :type certificate_signing_request_create_parameters:
         :py:class:`delphixpy.web.vo.CertificateSigningRequestCreateParameters`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/csr"
     response = engine.post(url, certificate_signing_request_create_parameters.to_dict(dirty=True) if certificate_signing_request_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -51,7 +47,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.CertificateSigningRequest`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/csr/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -66,7 +61,6 @@ def get_all(engine):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.CertificateSigningRequest`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/csr"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -83,7 +77,6 @@ def delete(engine, ref):
         ingRequest.CertificateSigningRequest` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/csr/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -99,12 +92,11 @@ def validate_dname(engine, x500_distinguished_name):
     :param x500_distinguished_name: Payload object.
     :type x500_distinguished_name:
         :py:class:`delphixpy.web.vo.X500DistinguishedName`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/csr/validateDname"
     response = engine.post(url, x500_distinguished_name.to_dict(dirty=True) if x500_distinguished_name else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
