@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "service.userPaths"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, user_path_storage=None):
@@ -34,14 +28,13 @@ def create(engine, user_path_storage=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param user_path_storage: Payload object.
     :type user_path_storage: :py:class:`delphixpy.web.vo.UserPathStorage`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/userPaths"
     response = engine.post(url, user_path_storage.to_dict(dirty=True) if user_path_storage else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -55,7 +48,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.UserPathStorage`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/userPaths/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -70,10 +62,9 @@ def get_all(engine, pathtype=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param pathtype: Type of path stored. *(permitted values:
         UPGRADE_STAGING_LOC)*
-    :type pathtype: ``TEXT_TYPE``
+    :type pathtype: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.UserPathStorage`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/userPaths"
     query_params = {"pathtype": pathtype}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -98,7 +89,6 @@ def update(engine, ref, user_path_storage=None):
     :param user_path_storage: Payload object.
     :type user_path_storage: :py:class:`delphixpy.web.vo.UserPathStorage`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/userPaths/%s" % ref
     response = engine.post(url, user_path_storage.to_dict(dirty=True) if user_path_storage else None)
     result = response_validator.validate(response, engine)
@@ -116,7 +106,6 @@ def delete(engine, ref):
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/userPaths/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
