@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +17,8 @@
 """
 Package "source"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy.web.source import operationTemplate
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get(engine, ref):
@@ -38,7 +32,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.Source`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -53,25 +46,24 @@ def get_all(engine, database=None, config=None, all_sources=None, repository=Non
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param database: List visible sources associated with the given container
         reference. Visible sources are of type LINKED or VIRTUAL.
-    :type database: ``TEXT_TYPE``
+    :type database: ``str``
     :param config: List visible sources associated with the given sourceconfig
         reference. Visible sources are of type LINKED or VIRTUAL.
-    :type config: ``TEXT_TYPE``
+    :type config: ``str``
     :param all_sources: List all sources associated with the given source
         container reference.
     :type all_sources: ``bool``
     :param repository: List sources associated with the given source repository
         reference.
-    :type repository: ``TEXT_TYPE``
+    :type repository: ``str``
     :param environment: List sources associated with the given source
         environment reference.
-    :type environment: ``TEXT_TYPE``
+    :type environment: ``str``
     :param include_hosts: Whether to include the list of hosts for each source
         in the response.
     :type include_hosts: ``bool``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.Source`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source"
     query_params = {"database": database, "config": config, "allSources": all_sources, "repository": repository, "environment": environment, "includeHosts": include_hosts}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -95,7 +87,6 @@ def update(engine, ref, source=None):
     :param source: Payload object.
     :type source: :py:class:`delphixpy.web.vo.Source`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s" % ref
     response = engine.post(url, source.to_dict(dirty=True) if source else None)
     result = response_validator.validate(response, engine)
@@ -115,7 +106,6 @@ def enable(engine, ref, source_enable_parameters=None):
     :type source_enable_parameters:
         :py:class:`delphixpy.web.vo.SourceEnableParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s/enable" % ref
     response = engine.post(url, source_enable_parameters.to_dict(dirty=True) if source_enable_parameters else None)
     result = response_validator.validate(response, engine)
@@ -135,7 +125,6 @@ def disable(engine, ref, source_disable_parameters=None):
     :type source_disable_parameters:
         :py:class:`delphixpy.web.vo.SourceDisableParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s/disable" % ref
     response = engine.post(url, source_disable_parameters.to_dict(dirty=True) if source_disable_parameters else None)
     result = response_validator.validate(response, engine)
@@ -155,7 +144,6 @@ def start(engine, ref, source_start_parameters=None):
     :type source_start_parameters:
         :py:class:`delphixpy.web.vo.SourceStartParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s/start" % ref
     response = engine.post(url, source_start_parameters.to_dict(dirty=True) if source_start_parameters else None)
     result = response_validator.validate(response, engine)
@@ -175,7 +163,6 @@ def stop(engine, ref, source_stop_parameters=None):
     :type source_stop_parameters:
         :py:class:`delphixpy.web.vo.SourceStopParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s/stop" % ref
     response = engine.post(url, source_stop_parameters.to_dict(dirty=True) if source_stop_parameters else None)
     result = response_validator.validate(response, engine)
@@ -195,7 +182,6 @@ def upgrade(engine, ref, source_upgrade_parameters=None):
     :type source_upgrade_parameters:
         :py:class:`delphixpy.web.vo.SourceUpgradeParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s/upgrade" % ref
     response = engine.post(url, source_upgrade_parameters.to_dict(dirty=True) if source_upgrade_parameters else None)
     result = response_validator.validate(response, engine)
@@ -213,7 +199,6 @@ def lock(engine, ref):
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s/lock" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
