@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "sourceconfig"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, source_config=None):
@@ -34,14 +28,13 @@ def create(engine, source_config=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param source_config: Payload object.
     :type source_config: :py:class:`delphixpy.web.vo.SourceConfig`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/sourceconfig"
     response = engine.post(url, source_config.to_dict(dirty=True) if source_config else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -54,7 +47,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.SourceConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/sourceconfig/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -70,20 +62,19 @@ def get_all(engine, repository=None, environment=None, cdb_config=None, pdb_conf
     :param repository: Restrict source configs to those belonging to the
         specified repository. This option is mutually exclusive with all other
         options.
-    :type repository: ``TEXT_TYPE``
+    :type repository: ``str``
     :param environment: Restrict source configs to those belonging to the
         specified environment. This option is mutually exclusive with all other
         options.
-    :type environment: ``TEXT_TYPE``
+    :type environment: ``str``
     :param cdb_config: Restrict PDB configs to those belonging to the specified
         CDB source config.
-    :type cdb_config: ``TEXT_TYPE``
+    :type cdb_config: ``str``
     :param pdb_config_only: Restrict source configs to be Oracle PDB configs
         only.
     :type pdb_config_only: ``bool``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.SourceConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/sourceconfig"
     query_params = {"repository": repository, "environment": environment, "cdbConfig": cdb_config, "pdbConfigOnly": pdb_config_only}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -107,7 +98,6 @@ def update(engine, ref, source_config=None):
     :param source_config: Payload object.
     :type source_config: :py:class:`delphixpy.web.vo.SourceConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/sourceconfig/%s" % ref
     response = engine.post(url, source_config.to_dict(dirty=True) if source_config else None)
     result = response_validator.validate(response, engine)
@@ -124,7 +114,6 @@ def delete(engine, ref):
         :py:class:`delphixpy.web.objects.SourceConfig.SourceConfig` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/sourceconfig/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -145,7 +134,6 @@ def validate_credentials(engine, ref, abstract_source_config_connectivity):
     :type abstract_source_config_connectivity:
         :py:class:`delphixpy.web.vo.AbstractSourceConfigConnectivity`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/sourceconfig/%s/validateCredentials" % ref
     response = engine.post(url, abstract_source_config_connectivity.to_dict(dirty=True) if abstract_source_config_connectivity else None)
     result = response_validator.validate(response, engine)
