@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,8 +17,6 @@
 """
 Package "storage.iscsi.target"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy import response_validator
 
 def create(engine, iscsi_target=None):
@@ -30,14 +27,13 @@ def create(engine, iscsi_target=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param iscsi_target: Payload object.
     :type iscsi_target: :py:class:`delphixpy.web.vo.IscsiTarget`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/iscsi/target"
     response = engine.post(url, iscsi_target.to_dict(dirty=True) if iscsi_target else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -50,7 +46,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.IscsiTarget`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/iscsi/target/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -65,7 +60,6 @@ def get_all(engine):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.IscsiTarget`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/iscsi/target"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -84,7 +78,6 @@ def update(engine, ref, iscsi_target=None):
     :param iscsi_target: Payload object.
     :type iscsi_target: :py:class:`delphixpy.web.vo.IscsiTarget`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/iscsi/target/%s" % ref
     response = engine.post(url, iscsi_target.to_dict(dirty=True) if iscsi_target else None)
     result = response_validator.validate(response, engine)
@@ -101,7 +94,6 @@ def delete(engine, ref):
         :py:class:`delphixpy.web.objects.IscsiTarget.IscsiTarget` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/iscsi/target/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -118,7 +110,6 @@ def login(engine, ref):
         :py:class:`delphixpy.web.objects.IscsiTarget.IscsiTarget` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/iscsi/target/%s/login" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -135,7 +126,6 @@ def logout(engine, ref):
         :py:class:`delphixpy.web.objects.IscsiTarget.IscsiTarget` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/iscsi/target/%s/logout" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -151,12 +141,11 @@ def discover(engine, iscsi_target_discover_parameters):
     :param iscsi_target_discover_parameters: Payload object.
     :type iscsi_target_discover_parameters:
         :py:class:`delphixpy.web.vo.IscsiTargetDiscoverParameters`
-    :rtype: ``list`` of ``TEXT_TYPE``
+    :rtype: ``list`` of ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/iscsi/target/discover"
     response = engine.post(url, iscsi_target_discover_parameters.to_dict(dirty=True) if iscsi_target_discover_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=True, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=True, raw_result=raw_result)
 
