@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "theme"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def create(engine, theme=None):
@@ -34,14 +28,13 @@ def create(engine, theme=None):
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param theme: Payload object.
     :type theme: :py:class:`delphixpy.web.vo.Theme`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme"
     response = engine.post(url, theme.to_dict(dirty=True) if theme else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -54,7 +47,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`delphixpy.web.vo.Theme`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -75,7 +67,6 @@ def get_all(engine, page_size=None, page_offset=None, active=None):
     :type active: ``bool``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.Theme`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme"
     query_params = {"pageSize": page_size, "pageOffset": page_offset, "active": active}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -99,7 +90,6 @@ def update(engine, ref, theme=None):
     :param theme: Payload object.
     :type theme: :py:class:`delphixpy.web.vo.Theme`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme/%s" % ref
     response = engine.post(url, theme.to_dict(dirty=True) if theme else None)
     result = response_validator.validate(response, engine)
@@ -116,7 +106,6 @@ def delete(engine, ref):
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -133,7 +122,6 @@ def set_active_theme(engine, theme_reference_parameter=None):
     :type theme_reference_parameter:
         :py:class:`delphixpy.web.vo.ThemeReferenceParameter`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme/setActiveTheme"
     response = engine.post(url, theme_reference_parameter.to_dict(dirty=True) if theme_reference_parameter else None)
     result = response_validator.validate(response, engine)
