@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "timeflow.oracle.log"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get_all(engine, database=None, timeflow=None, snapshot=None, from_date=None, to_date=None, from_scn=None, to_scn=None, page_size=None, page_offset=None, missing=None):
@@ -36,22 +30,22 @@ def get_all(engine, database=None, timeflow=None, snapshot=None, from_date=None,
     :param database: Return logs on all TimeFlows associated with the
         container. This option is mutually exclusive with the "TimeFlow" and
         "snapshot" options.
-    :type database: ``TEXT_TYPE``
+    :type database: ``str``
     :param timeflow: Return logs in the specified TimeFlow. This option is
         mutually exclusive with the "snapshot" and "database" options.
-    :type timeflow: ``TEXT_TYPE``
+    :type timeflow: ``str``
     :param snapshot: Return logs for the specified snapshot up to the next
         snapshot. This option is mutually exclusive with the "TimeFlow" and
         "database" options.
-    :type snapshot: ``TEXT_TYPE``
+    :type snapshot: ``str``
     :param from_date: Return logs created after this date.
-    :type from_date: ``TEXT_TYPE``
+    :type from_date: ``str``
     :param to_date: Return logs created before than this date.
-    :type to_date: ``TEXT_TYPE``
+    :type to_date: ``str``
     :param from_scn: Return logs with SCNs greater than or equal to this value.
-    :type from_scn: ``TEXT_TYPE``
+    :type from_scn: ``str``
     :param to_scn: Return logs with SCNs less than or equal to this value.
-    :type to_scn: ``TEXT_TYPE``
+    :type to_scn: ``str``
     :param page_size: Limit the number of logs returned.
     :type page_size: ``int``
     :param page_offset: Page offset within log list, in units of pageSize
@@ -61,7 +55,6 @@ def get_all(engine, database=None, timeflow=None, snapshot=None, from_date=None,
     :type missing: ``bool``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.OracleTimeflowLog`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/oracle/log"
     query_params = {"database": database, "timeflow": timeflow, "snapshot": snapshot, "fromDate": from_date, "toDate": to_date, "fromScn": from_scn, "toScn": to_scn, "pageSize": page_size, "pageOffset": page_offset, "missing": missing}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -82,7 +75,6 @@ def fetch(engine, log_fetch_ssh):
     :param log_fetch_ssh: Payload object.
     :type log_fetch_ssh: :py:class:`delphixpy.web.vo.LogFetchSSH`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/oracle/log/fetch"
     response = engine.post(url, log_fetch_ssh.to_dict(dirty=True) if log_fetch_ssh else None)
     result = response_validator.validate(response, engine)
