@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "timezone"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def get_all(engine, date=None):
@@ -36,10 +30,9 @@ def get_all(engine, date=None):
         date. If Daylight Saving Time is in effect at the specified date, the
         offset value is adjusted with the amount of daylight saving. If no date
         is specified then a default time of now is used.
-    :type date: ``TEXT_TYPE``
+    :type date: ``str``
     :rtype: ``list`` of :py:class:`delphixpy.web.vo.TimeZone`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timezone"
     query_params = {"date": date}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
