@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "usage"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy import response_validator
 
 def aggregate_ingested_size(engine, start_date=None, end_date=None):
@@ -36,12 +30,11 @@ def aggregate_ingested_size(engine, start_date=None, end_date=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.delphix_engine.DelphixEngine`
     :param start_date: Start time at which this information was sampled.
-    :type start_date: ``TEXT_TYPE``
+    :type start_date: ``str``
     :param end_date: End time at which this information was sampled.
-    :type end_date: ``TEXT_TYPE``
+    :type end_date: ``str``
     :rtype: :py:class:`delphixpy.web.vo.EngineAggregateIngestedSize`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/usage/aggregateIngestedSize"
     query_params = {"startDate": start_date, "endDate": end_date}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
