@@ -52,6 +52,10 @@ from delphixpy.web.objects.TCPStatsDatapointStream import TCPStatsDatapointStrea
 from delphixpy.web.objects.TCPStatsDatapoint import TCPStatsDatapoint
 from delphixpy.web.objects.VfsOpsDatapointStream import VfsOpsDatapointStream
 from delphixpy.web.objects.APIError import APIError
+from delphixpy.web.objects.ApiObjectAttributesRequest import ApiObjectAttributesRequest
+from delphixpy.web.objects.ApiObjectAttributes import ApiObjectAttributes
+from delphixpy.web.objects.ApiObjectExtraAttributes import ApiObjectExtraAttributes
+from delphixpy.web.objects.ApiObject import ApiObject
 from delphixpy.web.objects.AppDataAdditionalMountPoint import AppDataAdditionalMountPoint
 from delphixpy.web.objects.AppDataBaseTimeflow import AppDataBaseTimeflow
 from delphixpy.web.objects.AppDataCachedMountPoint import AppDataCachedMountPoint
@@ -122,8 +126,10 @@ from delphixpy.web.objects.AuthGetByPropertiesParameters import AuthGetByPropert
 from delphixpy.web.objects.AuthorizationConfig import AuthorizationConfig
 from delphixpy.web.objects.Authorization import Authorization
 from delphixpy.web.objects.AzureAuthentication import AzureAuthentication
+from delphixpy.web.objects.AzureCertificateAuthentication import AzureCertificateAuthentication
 from delphixpy.web.objects.AzureSecretsAuthentication import AzureSecretsAuthentication
 from delphixpy.web.objects.AzureVaultCredential import AzureVaultCredential
+from delphixpy.web.objects.AzureVaultTestParameters import AzureVaultTestParameters
 from delphixpy.web.objects.AzureVault import AzureVault
 from delphixpy.web.objects.BasePlatformParameters import BasePlatformParameters
 from delphixpy.web.objects.BaseSupportBundleParameters import BaseSupportBundleParameters
@@ -177,6 +183,7 @@ from delphixpy.web.objects.OracleDBConfigConnectivity import OracleDBConfigConne
 from delphixpy.web.objects.ConnectivityParameters import ConnectivityParameters
 from delphixpy.web.objects.SourceConfigConnectivity import SourceConfigConnectivity
 from delphixpy.web.objects.SSHConnectivity import SSHConnectivity
+from delphixpy.web.objects.ContainerStorageInfo import ContainerStorageInfo
 from delphixpy.web.objects.ContainerUtilizationInterval import ContainerUtilizationInterval
 from delphixpy.web.objects.ContainerUtilization import ContainerUtilization
 from delphixpy.web.objects.Container import Container
@@ -214,6 +221,7 @@ from delphixpy.web.objects.EndEntityCertificateReplaceParameters import EndEntit
 from delphixpy.web.objects.EndEntityCertificate import EndEntityCertificate
 from delphixpy.web.objects.EndEntityDsp import EndEntityDsp
 from delphixpy.web.objects.EndEntityHttps import EndEntityHttps
+from delphixpy.web.objects.EndEntityStunnel import EndEntityStunnel
 from delphixpy.web.objects.EndEntity import EndEntity
 from delphixpy.web.objects.EngineAggregateIngestedSize import EngineAggregateIngestedSize
 from delphixpy.web.objects.ErrorResult import ErrorResult
@@ -262,6 +270,7 @@ from delphixpy.web.objects.HostPrivilegeElevationSettings import HostPrivilegeEl
 from delphixpy.web.objects.HostRuntime import HostRuntime
 from delphixpy.web.objects.Host import Host
 from delphixpy.web.objects.HostedPasswordVault import HostedPasswordVault
+from delphixpy.web.objects.HostedVaultTestParameters import HostedVaultTestParameters
 from delphixpy.web.objects.HttpConnectorConfig import HttpConnectorConfig
 from delphixpy.web.objects.IdentifiableArrayElement import IdentifiableArrayElement
 from delphixpy.web.objects.InterfaceAddress import InterfaceAddress
@@ -345,6 +354,7 @@ from delphixpy.web.objects.MaskingServiceConfig import MaskingServiceConfig
 from delphixpy.web.objects.MigrateCompatibilityParameters import MigrateCompatibilityParameters
 from delphixpy.web.objects.MinimalPhoneHome import MinimalPhoneHome
 from delphixpy.web.objects.RuntimeMountInformation import RuntimeMountInformation
+from delphixpy.web.objects.MSSqlAdditionalDatabaseParameters import MSSqlAdditionalDatabaseParameters
 from delphixpy.web.objects.MSSqlAttachData import MSSqlAttachData
 from delphixpy.web.objects.MSSqlAvailabilityGroupDBConfig import MSSqlAvailabilityGroupDBConfig
 from delphixpy.web.objects.MSSqlAvailabilityGroupListener import MSSqlAvailabilityGroupListener
@@ -401,36 +411,6 @@ from delphixpy.web.objects.MSSqlTimeflowPoint import MSSqlTimeflowPoint
 from delphixpy.web.objects.MSSqlTimeflow import MSSqlTimeflow
 from delphixpy.web.objects.MSSqlUser import MSSqlUser
 from delphixpy.web.objects.MSSqlVirtualSource import MSSqlVirtualSource
-from delphixpy.web.objects.MySQLAttachData import MySQLAttachData
-from delphixpy.web.objects.MySQLBinlogCoordinates import MySQLBinlogCoordinates
-from delphixpy.web.objects.MySQLCompatibilityCriteria import MySQLCompatibilityCriteria
-from delphixpy.web.objects.MySQLCreateTransformationParameters import MySQLCreateTransformationParameters
-from delphixpy.web.objects.MySQLDBContainerRuntime import MySQLDBContainerRuntime
-from delphixpy.web.objects.MySQLDatabaseContainer import MySQLDatabaseContainer
-from delphixpy.web.objects.MySQLExistingBackupSyncParameters import MySQLExistingBackupSyncParameters
-from delphixpy.web.objects.MySQLExistingMySQLDumpSyncParameters import MySQLExistingMySQLDumpSyncParameters
-from delphixpy.web.objects.MySQLExportParameters import MySQLExportParameters
-from delphixpy.web.objects.MySQLGtidCoordinates import MySQLGtidCoordinates
-from delphixpy.web.objects.MySQLInstall import MySQLInstall
-from delphixpy.web.objects.MySQLLinkData import MySQLLinkData
-from delphixpy.web.objects.MySQLLinkedSource import MySQLLinkedSource
-from delphixpy.web.objects.MySQLNewMySQLDumpSyncParameters import MySQLNewMySQLDumpSyncParameters
-from delphixpy.web.objects.MySQLPlatformParameters import MySQLPlatformParameters
-from delphixpy.web.objects.MySQLProvisionParameters import MySQLProvisionParameters
-from delphixpy.web.objects.MySQLReplicationCoordinates import MySQLReplicationCoordinates
-from delphixpy.web.objects.MySQLServerConfig import MySQLServerConfig
-from delphixpy.web.objects.MySQLSnapshotRuntime import MySQLSnapshotRuntime
-from delphixpy.web.objects.MySQLSnapshot import MySQLSnapshot
-from delphixpy.web.objects.MySQLSourceConnectionInfo import MySQLSourceConnectionInfo
-from delphixpy.web.objects.MySQLSourceRuntime import MySQLSourceRuntime
-from delphixpy.web.objects.MySQLSource import MySQLSource
-from delphixpy.web.objects.MySQLStagingSource import MySQLStagingSource
-from delphixpy.web.objects.MySQLSyncParameters import MySQLSyncParameters
-from delphixpy.web.objects.MySQLTimeflowPoint import MySQLTimeflowPoint
-from delphixpy.web.objects.MySQLTimeflow import MySQLTimeflow
-from delphixpy.web.objects.MySQLVersion import MySQLVersion
-from delphixpy.web.objects.MySQLVirtualSource import MySQLVirtualSource
-from delphixpy.web.objects.MySQLXtraBackupSyncParameters import MySQLXtraBackupSyncParameters
 from delphixpy.web.objects.NamedKeyPairCredential import NamedKeyPairCredential
 from delphixpy.web.objects.NamedPasswordCredential import NamedPasswordCredential
 from delphixpy.web.objects.NamedUserObject import NamedUserObject
@@ -452,6 +432,7 @@ from delphixpy.web.objects.RemoteDelphixEngineInfo import RemoteDelphixEngineInf
 from delphixpy.web.objects.NetworkThroughputTestParameters import NetworkThroughputTestParameters
 from delphixpy.web.objects.NetworkThroughputTest import NetworkThroughputTest
 from delphixpy.web.objects.NfsConfig import NfsConfig
+from delphixpy.web.objects.NfsEncryptionConfig import NfsEncryptionConfig
 from delphixpy.web.objects.NotificationDrop import NotificationDrop
 from delphixpy.web.objects.Notification import Notification
 from delphixpy.web.objects.NTPConfig import NTPConfig
@@ -460,9 +441,12 @@ from delphixpy.web.objects.OAuth2FailedLoginRecord import OAuth2FailedLoginRecor
 from delphixpy.web.objects.OAuth2SuccessfulLoginRecord import OAuth2SuccessfulLoginRecord
 from delphixpy.web.objects.ObjectNotification import ObjectNotification
 from delphixpy.web.objects.ObjectStoreCacheHitsReport import ObjectStoreCacheHitsReport
+from delphixpy.web.objects.ObjectStoreMigrationStatus import ObjectStoreMigrationStatus
 from delphixpy.web.objects.ObjectStoreTestResult import ObjectStoreTestResult
 from delphixpy.web.objects.ObjectStoreTest import ObjectStoreTest
 from delphixpy.web.objects.ObjectStore import ObjectStore
+from delphixpy.web.objects.OciObjectStoreTest import OciObjectStoreTest
+from delphixpy.web.objects.OciObjectStore import OciObjectStore
 from delphixpy.web.objects.OKResult import OKResult
 from delphixpy.web.objects.OperationTemplate import OperationTemplate
 from delphixpy.web.objects.Operation import Operation
@@ -476,6 +460,7 @@ from delphixpy.web.objects.OracleBaseExternalLinkData import OracleBaseExternalL
 from delphixpy.web.objects.OracleBaseLinkData import OracleBaseLinkData
 from delphixpy.web.objects.OracleBaseProvisionParameters import OracleBaseProvisionParameters
 from delphixpy.web.objects.OracleBaseSourceRuntime import OracleBaseSourceRuntime
+from delphixpy.web.objects.OracleBaseSourcingPolicy import OracleBaseSourcingPolicy
 from delphixpy.web.objects.OracleBaseStagingLinkData import OracleBaseStagingLinkData
 from delphixpy.web.objects.OracleCharacterSet import OracleCharacterSet
 from delphixpy.web.objects.OracleClusterCreateParameters import OracleClusterCreateParameters
@@ -504,9 +489,12 @@ from delphixpy.web.objects.OracleEnableParameters import OracleEnableParameters
 from delphixpy.web.objects.OracleEnhancedExportParameters import OracleEnhancedExportParameters
 from delphixpy.web.objects.OracleExportASMStorageStrategy import OracleExportASMStorageStrategy
 from delphixpy.web.objects.OracleExportDBInPlaceTransferStrategy import OracleExportDBInPlaceTransferStrategy
+from delphixpy.web.objects.OracleExportDBTimeflowPointTransferStrategy import OracleExportDBTimeflowPointTransferStrategy
 from delphixpy.web.objects.OracleExportDBTransferStrategy import OracleExportDBTransferStrategy
+from delphixpy.web.objects.OracleExportOperationsPostV2P import OracleExportOperationsPostV2P
 from delphixpy.web.objects.OracleExportParameters import OracleExportParameters
 from delphixpy.web.objects.OracleExportPDBInPlaceTransferStrategy import OracleExportPDBInPlaceTransferStrategy
+from delphixpy.web.objects.OracleExportPDBTimeflowPointTransferStrategy import OracleExportPDBTimeflowPointTransferStrategy
 from delphixpy.web.objects.OracleExportPDBTransferStrategy import OracleExportPDBTransferStrategy
 from delphixpy.web.objects.OracleExportStorageStrategy import OracleExportStorageStrategy
 from delphixpy.web.objects.OracleExportTimeflowFilesystemLayout import OracleExportTimeflowFilesystemLayout
@@ -560,6 +548,7 @@ from delphixpy.web.objects.OracleStagingPushSyncParameters import OracleStagingP
 from delphixpy.web.objects.OracleStagingPushSyncStrategy import OracleStagingPushSyncStrategy
 from delphixpy.web.objects.OracleStagingSourceParameters import OracleStagingSourceParameters
 from delphixpy.web.objects.OracleStagingSource import OracleStagingSource
+from delphixpy.web.objects.OracleStagingSourcingPolicy import OracleStagingSourcingPolicy
 from delphixpy.web.objects.OracleStartParameters import OracleStartParameters
 from delphixpy.web.objects.OracleStopParameters import OracleStopParameters
 from delphixpy.web.objects.OracleSyncFromExternalParameters import OracleSyncFromExternalParameters
@@ -592,31 +581,6 @@ from delphixpy.web.objects.PemCertificate import PemCertificate
 from delphixpy.web.objects.PemClientCertificate import PemClientCertificate
 from delphixpy.web.objects.Permission import Permission
 from delphixpy.web.objects.PersistentObject import PersistentObject
-from delphixpy.web.objects.PgSQLAttachData import PgSQLAttachData
-from delphixpy.web.objects.PgSQLCompatibilityCriteria import PgSQLCompatibilityCriteria
-from delphixpy.web.objects.PgSQLCreateTransformationParameters import PgSQLCreateTransformationParameters
-from delphixpy.web.objects.PgSQLDatabaseTemplate import PgSQLDatabaseTemplate
-from delphixpy.web.objects.PgSQLDBClusterConfig import PgSQLDBClusterConfig
-from delphixpy.web.objects.PgSQLDBConfig import PgSQLDBConfig
-from delphixpy.web.objects.PgSQLDBContainerRuntime import PgSQLDBContainerRuntime
-from delphixpy.web.objects.PgSQLDatabaseContainer import PgSQLDatabaseContainer
-from delphixpy.web.objects.PgSQLExportParameters import PgSQLExportParameters
-from delphixpy.web.objects.PgSQLHBAEntry import PgSQLHBAEntry
-from delphixpy.web.objects.PgSQLIdentEntry import PgSQLIdentEntry
-from delphixpy.web.objects.PgSQLInstall import PgSQLInstall
-from delphixpy.web.objects.PgSQLLinkData import PgSQLLinkData
-from delphixpy.web.objects.PgSQLLinkedSource import PgSQLLinkedSource
-from delphixpy.web.objects.PgSQLPlatformParameters import PgSQLPlatformParameters
-from delphixpy.web.objects.PgSQLProvisionParameters import PgSQLProvisionParameters
-from delphixpy.web.objects.PgSQLSnapshot import PgSQLSnapshot
-from delphixpy.web.objects.PgSQLSourceConnectionInfo import PgSQLSourceConnectionInfo
-from delphixpy.web.objects.PgSQLSourceRuntime import PgSQLSourceRuntime
-from delphixpy.web.objects.PgSQLSource import PgSQLSource
-from delphixpy.web.objects.PgSQLStagingSource import PgSQLStagingSource
-from delphixpy.web.objects.PgSQLSyncParameters import PgSQLSyncParameters
-from delphixpy.web.objects.PgSQLTimeflowPoint import PgSQLTimeflowPoint
-from delphixpy.web.objects.PgSQLTimeflow import PgSQLTimeflow
-from delphixpy.web.objects.PgSQLVirtualSource import PgSQLVirtualSource
 from delphixpy.web.objects.PhoneHomeService import PhoneHomeService
 from delphixpy.web.objects.PluginDiscoveryDefinition import PluginDiscoveryDefinition
 from delphixpy.web.objects.PluginLinkedDirectSourceDefinition import PluginLinkedDirectSourceDefinition
@@ -653,7 +617,9 @@ from delphixpy.web.objects.RepaveConfigurableMetadata import RepaveConfigurableM
 from delphixpy.web.objects.RepaveDNSConfig import RepaveDNSConfig
 from delphixpy.web.objects.RepaveEngineSummary import RepaveEngineSummary
 from delphixpy.web.objects.RepavePrepareParameters import RepavePrepareParameters
-from delphixpy.web.objects.RepavePreview import RepavePreview
+from delphixpy.web.objects.BlockStorageRepavePreviewParameters import BlockStorageRepavePreviewParameters
+from delphixpy.web.objects.RepavePreviewParameters import RepavePreviewParameters
+from delphixpy.web.objects.RepavePreviewResult import RepavePreviewResult
 from delphixpy.web.objects.RepaveStatus import RepaveStatus
 from delphixpy.web.objects.ReplicaRetentionPolicy import ReplicaRetentionPolicy
 from delphixpy.web.objects.ReplicationList import ReplicationList
@@ -744,6 +710,9 @@ from delphixpy.web.objects.StorageDevice import StorageDevice
 from delphixpy.web.objects.StorageTestParameters import StorageTestParameters
 from delphixpy.web.objects.StorageTestResult import StorageTestResult
 from delphixpy.web.objects.StorageTest import StorageTest
+from delphixpy.web.objects.SuperuserSessionLogDeleteRecord import SuperuserSessionLogDeleteRecord
+from delphixpy.web.objects.SuperuserSessionLogDownloadRecord import SuperuserSessionLogDownloadRecord
+from delphixpy.web.objects.SuperuserSession import SuperuserSession
 from delphixpy.web.objects.SupportBundleGenerateParameters import SupportBundleGenerateParameters
 from delphixpy.web.objects.SupportBundleUploadParameters import SupportBundleUploadParameters
 from delphixpy.web.objects.SupportBundleConfiguration import SupportBundleConfiguration
@@ -758,6 +727,7 @@ from delphixpy.web.objects.SyslogConfig import SyslogConfig
 from delphixpy.web.objects.SyslogServer import SyslogServer
 from delphixpy.web.objects.AdvancedSettingsInfo import AdvancedSettingsInfo
 from delphixpy.web.objects.SystemInitializationParameters import SystemInitializationParameters
+from delphixpy.web.objects.SystemPackage import SystemPackage
 from delphixpy.web.objects.SystemStatus import SystemStatus
 from delphixpy.web.objects.SystemInfo import SystemInfo
 from delphixpy.web.objects.SystemKeyCredential import SystemKeyCredential
@@ -823,6 +793,7 @@ from delphixpy.web.objects.UserObject import UserObject
 from delphixpy.web.objects.UserPathStorage import UserPathStorage
 from delphixpy.web.objects.User import User
 from delphixpy.web.objects.ValidateJavaParameters import ValidateJavaParameters
+from delphixpy.web.objects.ValidateNTPParameters import ValidateNTPParameters
 from delphixpy.web.objects.ValidateSMTPParameters import ValidateSMTPParameters
 from delphixpy.web.objects.AbstractVaultCredential import AbstractVaultCredential
 from delphixpy.web.objects.VerifyVersionParameters import VerifyVersionParameters
